@@ -165,6 +165,10 @@
 #' created. The default, \code{where = is.na(data)}, specifies that the
 #' missing data should be imputed. The \code{where} argument may be used to
 #' overimpute observed data, or to skip imputations for selected missing values.
+#' Note: Imputation methods that generate imptutations outside of
+#' \code{mice}, like \code{mice.impute.panImpute()} may depend on a complete
+#' predictor space. In that case, a custom \code{where} matrix can not be
+#' specified.
 #' @param blocks List of vectors with variable names per block. List elements
 #' may be named to identify blocks. Variables within a block are
 #' imputed by a multivariate imputation method
@@ -222,9 +226,7 @@
 #' Use \code{print=FALSE} for silent computation.
 #' @param seed An integer that is used as argument by the \code{set.seed()} for
 #' offsetting the random number generator. Default is to leave the random number
-#' generator alone. Versions later than 3.13.11 reset the random generator to the
-#' state before calling \code{mice()}. This effectively isolates the \code{mice}
-#' random generator from the calling environment.
+#' generator alone.
 #' @param data.init A data frame of the same size and type as \code{data},
 #' without missing data, used to initialize imputations before the start of the
 #' iterative process.  The default \code{NULL} implies that starting imputation
@@ -281,6 +283,28 @@
 #'
 #' # imputation on mixed data with a different method per column
 #' mice(nhanes2, meth = c("sample", "pmm", "logreg", "norm"))
+#'
+#' \dontrun{
+#' # example where we fit the imputation model on the train data
+#' # and apply the model to impute the test data
+#' set.seed(123)
+#' ignore <- sample(c(TRUE, FALSE), size = 25, replace = TRUE, prob = c(0.3, 0.7))
+#'
+#' # scenario 1: train and test in the same dataset
+#' imp <- mice(nhanes2, m = 2, ignore = ignore, print = FALSE, seed = 22112)
+#' imp.test1 <- filter(imp, ignore)
+#' imp.test1$data
+#' complete(imp.test1, 1)
+#' complete(imp.test1, 2)
+#'
+#' # scenario 2: train and test in separate datasets
+#' traindata <- nhanes2[!ignore, ]
+#' testdata <- nhanes2[ignore, ]
+#' imp.train <- mice(traindata, m = 2, print = FALSE, seed = 22112)
+#' imp.test2 <- mice.mids(imp.train, newdata = testdata)
+#' complete(imp.test2, 1)
+#' complete(imp.test2, 2)
+#' }
 #' @export
 mice <- function(data,
                  m = 5,
@@ -302,12 +326,7 @@ mice <- function(data,
   call <- match.call()
   check.deprecated(...)
 
-  # set local seed, reset random state generator after function aborts
-  if (is.na(seed)) {
-    withr::local_preserve_seed()
-  } else {
-    withr::local_seed(seed)
-  }
+  if (!is.na(seed)) set.seed(seed)
 
   # check form of data and m
   data <- check.dataform(data)
@@ -459,8 +478,10 @@ mice <- function(data,
     ignore = ignore,
     seed = seed,
     iteration = q$iteration,
-    lastSeedValue = get(".Random.seed", envir = globalenv(), mode = "integer",
-                        inherits = FALSE),
+    lastSeedValue = get(".Random.seed",
+      envir = globalenv(), mode = "integer",
+      inherits = FALSE
+    ),
     chainMean = q$chainMean,
     chainVar = q$chainVar,
     loggedEvents = loggedEvents,
